@@ -9,7 +9,6 @@ from __future__ import absolute_import, division, print_function, \
     with_statement, unicode_literals
 
 import os
-import pipes
 import logging
 
 from . import util, formats, exc
@@ -76,7 +75,7 @@ class Window(util.TmuxMappingObject, util.TmuxRelationalObject):
         :rtype: :class:`Server.tmux`
 
         """
-        if not len([arg for arg in args if '-t' in str(arg)]):
+        if not any(arg.startswith('-t') for arg in args):
             args = ('-t', self.get('window_id')) + args
 
         return self.server.tmux(cmd, *args, **kwargs)
@@ -378,7 +377,6 @@ class Window(util.TmuxMappingObject, util.TmuxRelationalObject):
         if start_directory:
             # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
             start_directory = os.path.expanduser(start_directory)
-            start_directory = pipes.quote(start_directory)
             tmux_args += ('-c%s' % start_directory,)
 
         if not attach:
